=======
AUTHORS
=======

- Andrew Pinkham http://andrewsforge.com
- Jim Illback jimillback01@gmail.com
- Josh Schneier https://github.com/jschneier
- Kenneth Johnson https://github.com/securedirective
- Russell Keith-Magee http://cecinestpasun.com
